@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2022-06-01 17:41:10
-:LastEditTime: 2022-11-21 19:57:57
+:LastEditTime: 2022-11-22 16:42:20
 :LastEditors: Kangwenbin
 :Description: 
 """
@@ -10,7 +10,7 @@ from seven_studio.handlers.studio_base import *
 from seven_shell_studio.models.db_models.goods.goods_model import *
 from seven_shell_studio.models.db_models.exchange.exchange_model_ex import *
 from seven_shell_studio.models.db_models.inventory.inventory_record_model import *
-class GoodsManageHandle(StudioBaseHandler):
+class GoodsManageHandler(StudioBaseHandler):
 
     @filter_check_params(["goods_id"])
     @login_filter(True)
@@ -191,7 +191,7 @@ class GoodsManageHandle(StudioBaseHandler):
         self.reponse_json_success()
 
 
-class ExchangeListHandle(StudioBaseHandler):
+class ExchangeListHandler(StudioBaseHandler):
     @filter_check_params(["page_index", "page_size"])
     @login_filter(True)
     def get_async(self, *args, **kwargs):
@@ -240,7 +240,7 @@ class ExchangeListHandle(StudioBaseHandler):
 
         # 获取兑换列表
         exchange_list,exchange_count = ExchangeModelEx().get_exchange_page_list(condition,"a.order_id,a.goods_id,b.goods_name,b.goods_icon,a.user_id,a.nick_name,a.goods_integral,a.goods_code,a.goods_count,a.add_time",
-                            limit = f"{(page_index-1)*page_size},{page_size}",params=param_list)
+                            limit = f"{(page_index-1)*page_size},{page_size}",params=param_list,order_by="a.id desc")
         
         ret_model = {
             "count":exchange_count,
@@ -250,7 +250,7 @@ class ExchangeListHandle(StudioBaseHandler):
         return self.reponse_json_success(ret_model)
 
 
-class GoodsListHandle(StudioBaseHandler):
+class GoodsListHandler(StudioBaseHandler):
 
     @filter_check_params(["page_index", "page_size"])
     def get_async(self, *args, **kwargs):
